@@ -30,5 +30,3 @@ class Basics:
                 self.value /= value
         return self.value
 
-def main():
-    return Basics
